aboutsummaryrefslogtreecommitdiff
path: root/mod/messages/index.php
diff options
context:
space:
mode:
authorbrettp <brettp@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-03-04 02:21:28 +0000
committerbrettp <brettp@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-03-04 02:21:28 +0000
commite209ef52571b1e0f6a3937d3e88c9150c384994c (patch)
tree099090098a2b955af06a9ba02762d0fe79e08ae4 /mod/messages/index.php
parent59da34fb0c7a590db505777742ca21e1dd5b5cba (diff)
downloadelgg-e209ef52571b1e0f6a3937d3e88c9150c384994c.tar.gz
elgg-e209ef52571b1e0f6a3937d3e88c9150c384994c.tar.bz2
Merged messages interface changes.
git-svn-id: http://code.elgg.org/elgg/trunk@5270 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'mod/messages/index.php')
-rw-r--r--mod/messages/index.php105
1 files changed, 51 insertions, 54 deletions
diff --git a/mod/messages/index.php b/mod/messages/index.php
index b9cfd1097..e5124a71a 100644
--- a/mod/messages/index.php
+++ b/mod/messages/index.php
@@ -1,55 +1,52 @@
<?php
-
- /**
- * Elgg messages inbox page
- *
- * @package ElggMessages
- * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
- * @author Curverider Ltd <info@elgg.com>
- * @copyright Curverider Ltd 2008-2010
- * @link http://elgg.com/
- */
-
- // Load Elgg engine
- require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
-
- // You need to be logged in!
- gatekeeper();
-
- // Get offset
- $offset = get_input('offset',0);
-
- // Set limit
- $limit = 10;
-
- // Get the logged in user, you can't see other peoples messages so use session id
- $page_owner = $_SESSION['user'];
- set_page_owner($page_owner->getGUID());
-
- // Get the user's inbox, this will be all messages where the 'toId' field matches their guid
- $messages = elgg_get_entities_from_metadata(array(
- 'type' => 'object',
- 'subtype' => 'messages',
- 'metadata_name' => 'toId',
- 'metadata_value' => $page_owner->getGUID(),
- 'owner_guid' => $page_owner->guid,
- 'limit' => $limit + 1,
- 'offset' => $offset
- ));
-
- // Set the page title
- $area2 = elgg_view_title(elgg_echo("messages:inbox"));
-
- // Display them. The last variable 'page_view' is to allow the view page to know where this data is coming from,
- // in this case it is the inbox, this is necessary to ensure the correct display
- // $area2 .= elgg_view("messages/view",array('entity' => $messages, 'page_view' => "inbox", 'limit' => $limit, 'offset' => $offset));
- $area2 .= elgg_view("messages/forms/view",array('entity' => $messages, 'page_view' => "inbox", 'limit' => $limit, 'offset' => $offset));
-
- // format
- $body = elgg_view_layout("two_column_left_sidebar", '', $area2);
-
-
- // Draw page
- page_draw(sprintf(elgg_echo('messages:user'),$page_owner->name),$body);
-
-?>
+/**
+ * Elgg messages inbox page
+ *
+ * @package ElggMessages
+ * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
+ * @author Curverider Ltd <info@elgg.com>
+ * @copyright Curverider Ltd 2008-2010
+ * @link http://elgg.com/
+*/
+
+
+require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
+gatekeeper();
+global $CONFIG;
+
+$offset = get_input('offset', 0);
+$limit = 10;
+
+// Get the logged in user, you can't see other peoples messages so use session id
+$page_owner = get_loggedin_user();
+set_page_owner($page_owner->getGUID());
+
+// Get the user's inbox, this will be all messages where the 'toId' field matches their guid
+$messages = elgg_get_entities_from_metadata(array(
+ 'type' => 'object',
+ 'subtype' => 'messages',
+ 'metadata_name' => 'toId',
+ 'metadata_value' => $page_owner->getGUID(),
+ 'owner_guid' => $page_owner->guid,
+ 'limit' => $limit + 1,
+ 'offset' => $offset
+));
+
+// Set the page title
+$area2 = "<div id='content_header'><div class='content_header_title'>";
+$area2 .= elgg_view_title(elgg_echo("messages:inbox"))."</div>";
+$area2 .= "<div class='content_header_options'><a class='action_button' href='{$CONFIG->wwwroot}mod/messages/send.php'>" . elgg_echo('messages:compose') . "</a></div></div>";
+
+// Display them. The last variable 'page_view' is to allow the view page to know where this data is coming from,
+// in this case it is the inbox, this is necessary to ensure the correct display
+$area2 .= elgg_view("messages/forms/view",array('entity' => $messages, 'page_view' => "inbox", 'limit' => $limit, 'offset' => $offset));
+
+// Sidebar menu options
+//$area3 = elgg_view("messages/menu_options", array('context' => 'inbox'));
+
+// format
+$body = elgg_view_layout("one_column_with_sidebar",'',$area2);
+
+
+// Draw page
+page_draw(sprintf(elgg_echo('messages:user'),$page_owner->name),$body); \ No newline at end of file